@@ -24,20 +24,11 @@ class connector:
 		token = json.loads(reply.text)
 		self.head = {'Authorization' : "Bearer {}".format(token['access_token'])}
 		self.url = 'https://api.intra.42.fr/v2'
-		if 'verbose' in kwargs:
+		if 'v' in kwargs:
 			self.verbose = True
 			print(self.BLUE + "Verbose activate." + self.DEFAULT)
 		print(self.GREEN + "Connector ready to use!" + self.DEFAULT)
 
-	def unverbose(self):
-		print(self.BLUE + "Verbose desactivate." + self.DEFAULT)
-		self.verbose = False
-
-	def verbose(self):
-		print(self.BLUE + "Verbose activate." + self.DEFAULT)
-		self.verbose = True
-
-
 	def dot_env_parser(self):
 		ret = {}
 		try :
@@ -157,3 +148,15 @@ class connector:
 			self.put_in_file(json.loads(reply.text), name='error.json')
 			print(self.RED + err + 'on DELETE ' + url + self.DEFAULT)
 		return (json.loads(reply.text))
+
+	def build_list_email(self, all_logins):
+	print("[", end='')
+	i = 0
+	for login in all_logins:
+		print("\""+ login + "@student.42.fr\"", end='')
+		if i != len(all_logins) - 1:
+			print(",",end='')
+		i+=1
+	print("]")
+	for login in all_logins:
+		print(login)
